// symbol morphs in the page
for (const e of document.querySelectorAll(".symbolMorph")) {
  let symb = e.dataset?.symbolMorph;
  let sz = e.dataset?.size ?? 16;
  let col = e.dataset?.color ?? "#f0f";
  if (!symb) {
    continue;
  }
  let canvas = document.createElement("canvas"),
      ctx = canvas.getContext("2d");
  canvas.width = sz;
  canvas.height = sz;
  let szRem = sz / 16;
  canvas.style.width = szRem + "rem";
  canvas.style.height = szRem + "rem";
  canvas.setAttribute("role", "img");
  canvas.setAttribute("aria-label", e.innerText);
  e.innerText = "";
  e.appendChild(canvas);
  new SymbolMorph(symb, sz).renderShape(ctx, col);
}

const FPS = 67,
      worldCanvas = document.querySelector("#world");

let world = new WorldMorph(worldCanvas, /* fill? */ false),
    lastTime = 0;

const loop = (timestamp) => {
  requestAnimationFrame(loop);
  if (timestamp - lastTime < 1000 / FPS) {
    return;
  }
  world.doOneCycle();
  lastTime = Math.max(
    lastTime + 1000 / FPS,
    timestamp - 1000 / FPS
  );
};

let ide = new IDE_Morph({
  "mode": "presentation",
  "noExitWarning": true,
  "preserveTitle": true,
});
ide.openIn(world);
fetch(window.snapXmlHref).then(response => response.text()).then((x) => {
  ide.loadProjectXML(x);
  ide.setEmbedMode(true);
  ide.togglePerformerMode(true);
});
/*
ide.loadProjectXML(
  document.querySelector("#snapData").innerText.replaceAll("scr1pt", "script")
);
ide.setEmbedMode(true);
ide.togglePerformerMode(true);
*/
requestAnimationFrame(loop);
document.querySelector("#flag").addEventListener("click", () => {
  console.log("#flag");
  ide.pressStart();
}, false);
document.querySelector("#pause").addEventListener("click", () => {
  console.log("#pause");
  ide.togglePauseResume();
}, false);
document.querySelector("#stop").addEventListener("click", () => {
  console.log("#stop");
  ide.stopAllScripts();
}, false);

// for "responsive" design
const onResize = function () {
  // canvas size
  let w = worldCanvas.getBoundingClientRect().width,
      h = Math.round(w * 0.75);
  worldCanvas.width = w;
  worldCanvas.height = h;
  worldCanvas.style.width = w + "px";
  worldCanvas.style.height = h + "px";
  // world morph
  world.changed();
  world.setWidth(w);
  world.setHeight(h);
  world.rerender();
  world.children.forEach(child => {
    if (child.reactToWorldResize) child.reactToWorldResize(world.bounds.copy());
  });
};

screen.orientation.addEventListener("change", onResize);
window.addEventListener("resize", onResize);
onResize();

